@@ -1,12 +1,10 @@
-
-import pkg_resources
+from .version import __version__
 
 
 def get_common_headers():
     """Get the headers for the requests."""
     return {
         "x-moralis-platform": 'Python SDK',
+        "x-moralis-platform-version": __version__,
         "x-moralis-build-target": 'python',
-        "x-moralis-build-target": pkg_resources.get_distribution('moralis').version,
     }
- 
