@@ -32,6 +32,7 @@ from openapi_evm_api.apis.paths.address import Address
 from openapi_evm_api.apis.paths.address_verbose import AddressVerbose
 from openapi_evm_api.apis.paths.transaction_transaction_hash_internal_transactions import TransactionTransactionHashInternalTransactions
 from openapi_evm_api.apis.paths.transaction_transaction_hash import TransactionTransactionHash
+from openapi_evm_api.apis.paths.transaction_transaction_hash_verbose import TransactionTransactionHashVerbose
 from openapi_evm_api.apis.paths.block_block_number_or_hash import BlockBlockNumberOrHash
 from openapi_evm_api.apis.paths.date_to_block import DateToBlock
 from openapi_evm_api.apis.paths.address_logs import AddressLogs
@@ -79,6 +80,7 @@ PathToApi = typing_extensions.TypedDict(
         PathValues.ADDRESS_VERBOSE: AddressVerbose,
         PathValues.TRANSACTION_TRANSACTION_HASH_INTERNALTRANSACTIONS: TransactionTransactionHashInternalTransactions,
         PathValues.TRANSACTION_TRANSACTION_HASH: TransactionTransactionHash,
+        PathValues.TRANSACTION_TRANSACTION_HASH_VERBOSE: TransactionTransactionHashVerbose,
         PathValues.BLOCK_BLOCK_NUMBER_OR_HASH: BlockBlockNumberOrHash,
         PathValues.DATE_TO_BLOCK: DateToBlock,
         PathValues.ADDRESS_LOGS: AddressLogs,
@@ -127,6 +129,7 @@ path_to_api = PathToApi(
         PathValues.ADDRESS_VERBOSE: AddressVerbose,
         PathValues.TRANSACTION_TRANSACTION_HASH_INTERNALTRANSACTIONS: TransactionTransactionHashInternalTransactions,
         PathValues.TRANSACTION_TRANSACTION_HASH: TransactionTransactionHash,
+        PathValues.TRANSACTION_TRANSACTION_HASH_VERBOSE: TransactionTransactionHashVerbose,
         PathValues.BLOCK_BLOCK_NUMBER_OR_HASH: BlockBlockNumberOrHash,
         PathValues.DATE_TO_BLOCK: DateToBlock,
         PathValues.ADDRESS_LOGS: AddressLogs,
