@@ -21,6 +21,15 @@ from openapi_streams.model.addresses_types_addresses_remove import AddressesType
 from openapi_streams.model.addresses_types_addresses_response import AddressesTypesAddressesResponse
 from openapi_streams.model.addresses_types_uuid import AddressesTypesUUID
 from openapi_streams.model.advanced_options import AdvancedOptions
+from openapi_streams.model.aptos_block import AptosBlock
+from openapi_streams.model.aptos_coin import AptosCoin
+from openapi_streams.model.aptos_coin_deposit import AptosCoinDeposit
+from openapi_streams.model.aptos_coin_transfer import AptosCoinTransfer
+from openapi_streams.model.aptos_coin_withdrawal import AptosCoinWithdrawal
+from openapi_streams.model.aptos_create_stream_type import AptosCreateStreamType
+from openapi_streams.model.aptos_network import AptosNetwork
+from openapi_streams.model.aptos_stream_type import AptosStreamType
+from openapi_streams.model.aptos_transaction import AptosTransaction
 from openapi_streams.model.block import Block
 from openapi_streams.model.get_native_balances import GetNativeBalances
 from openapi_streams.model.history_model import HistoryModel
@@ -29,7 +38,9 @@ from openapi_streams.model.history_types_history_response import HistoryTypesHis
 from openapi_streams.model.history_types_uuid import HistoryTypesUUID
 from openapi_streams.model.internal_transaction import InternalTransaction
 from openapi_streams.model.log import Log
+from openapi_streams.model.partial_aptos_create_stream_type import PartialAptosCreateStreamType
 from openapi_streams.model.partial_streams_types_streams_model_create import PartialStreamsTypesStreamsModelCreate
+from openapi_streams.model.pick_aptos_stream_type_status_or_status_message import PickAptosStreamTypeStatusOrStatusMessage
 from openapi_streams.model.settings_region import SettingsRegion
 from openapi_streams.model.settings_types_settings_model import SettingsTypesSettingsModel
 from openapi_streams.model.stream_types_uuid import StreamTypesUUID
@@ -47,5 +58,6 @@ from openapi_streams.model.trigger_output import TriggerOutput
 from openapi_streams.model.uuid import UUID
 from openapi_streams.model.usage_stats_streams import UsageStatsStreams
 from openapi_streams.model.usagestats_types_usage_stats_model import UsagestatsTypesUsageStatsModel
+from openapi_streams.model.webhook_types_aptos_webhook import WebhookTypesAptosWebhook
 from openapi_streams.model.webhook_types_i_tiny_payload import WebhookTypesITinyPayload
 from openapi_streams.model.webhook_types_i_webhook_un_parsed import WebhookTypesIWebhookUnParsed
